/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

/**
 * @brief Anything entity-related.
 */
#ifndef CAOSDB_ENTITY_H
#define CAOSDB_ENTITY_H

#include <memory>                           // for shared_ptr
#include <string>                           // for string
#include "caosdb/entity/v1alpha1/main.pb.h" // for Entity

namespace caosdb::entity {
using ProtoEntity = caosdb::entity::v1alpha1::Entity;

/**
 * Entity ID.
 */
class EntityID {
private:
  std::shared_ptr<std::string> id;

public:
  explicit EntityID(const std::string &id);
  explicit EntityID(const std::shared_ptr<std::string> &id);
};

/**
 * @brief Wrapper for the Protobuf entity.
 */
class Entity {
private:
  EntityID id;
  std::shared_ptr<ProtoEntity> delegate;

public:
  explicit Entity(ProtoEntity *delegate);
  [[nodiscard]] auto GetId() const -> EntityID;
  auto SetId(EntityID id) -> void;
  [[nodiscard]] auto GetName() const -> std::string;
  [[nodiscard]] auto GetDescription() const -> std::string;
};

} // namespace caosdb::entity
#endif
