/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#include "caosdb/entity.h"
#include <utility>

namespace caosdb::entity {

EntityID::EntityID(const std::string &id) {
  this->id = std::make_shared<std::string>(id);
}

EntityID::EntityID(const std::shared_ptr<std::string> &id) {
  this->id = std::make_shared<std::string>(*id);
}

Entity::Entity(ProtoEntity *delegate)
  : id(EntityID(delegate->eid())), delegate(delegate) {}

[[nodiscard]] auto Entity::GetDescription() const -> std::string {
  return this->delegate->description();
}
[[nodiscard]] auto Entity::GetId() const -> EntityID { return this->id; }

auto Entity::SetId(EntityID id) -> void { this->id = std::move(id); }

} // namespace caosdb::entity
